@@ -1,4 +1,4 @@
-"""Defines pipelines for processing Pandas.DataFrame-based datasets.
+"""Defines pipelines for processing pandas.DataFrame-based datasets.
 
 >>> import pdpipe as pdp
 >>> pipeline = pdp.ColDrop('Name') + pdp.Bin({'Speed': [0,5]})
@@ -24,60 +24,60 @@ The main interface of sub-classes of this base class with it is through the
 `columns`, `exclude_columns` and `none_columns` constructor arguments, and the
 "private" `_get_columns(df, fit)` method:
 
-    * Any extending subclass should accept the `columns` constructor parameter
-      and forward it, without transforming it, to the constructor of
-      ColumnsBasedPipelineStage. E.g.
-      `super().__init__(columns=columns, **kwargs)`. See the implementation of
-      any such extending class for a more complete example.
+* Any extending subclass should accept the `columns` constructor parameter
+  and forward it, without transforming it, to the constructor of
+  ColumnsBasedPipelineStage. E.g.
+  `super().__init__(columns=columns, **kwargs)`. See the implementation of
+  any such extending class for a more complete example.
 
-    * Extending subclasses can decide if they want to expose the
-      `exclude_columns` parameter or not. Note that most of its functionality
-      can anyway be gained by providing the `columns` parameter with a column
-      qualifier object that is a difference between two column qualifiers; e.g.
-      `columns=cq.OfDtype(np.number) - cq.OfDtype(np.int64)` is equivalent to
-      providing `columns=cq.OfDtype(np.number),
-      exclude_columns=cq.OfDtype(np.int64)`. However, exposing the
-      `exclude_columns` parameter can allow for specific unique behaviours; for
-      example, if the `none_columns` parametet - which configures the behavior
-      when `columns` is provided with `None` - is set with
-      a `cq.OfDtypes('category')` column qualifier, which means that all
-      categorical columns are selected when `columns=None`, then exposing
-      `exclude_columns` allows easy specification of the "all categorical
-      columns except X" by just giving a column qualifier capturing X to
-      `exclude_columns`, instead of having to reconstruct the default column
-      qualifier by hand and substract from it the one representing X.
+* Extending subclasses can decide if they want to expose the
+  `exclude_columns` parameter or not. Note that most of its functionality
+  can anyway be gained by providing the `columns` parameter with a column
+  qualifier object that is a difference between two column qualifiers; e.g.
+  `columns=cq.OfDtype(np.number) - cq.OfDtype(np.int64)` is equivalent to
+  providing `columns=cq.OfDtype(np.number),
+  exclude_columns=cq.OfDtype(np.int64)`. However, exposing the
+  `exclude_columns` parameter can allow for specific unique behaviours; for
+  example, if the `none_columns` parametet - which configures the behavior
+  when `columns` is provided with `None` - is set with
+  a `cq.OfDtypes('category')` column qualifier, which means that all
+  categorical columns are selected when `columns=None`, then exposing
+  `exclude_columns` allows easy specification of the "all categorical
+  columns except X" by just giving a column qualifier capturing X to
+  `exclude_columns`, instead of having to reconstruct the default column
+  qualifier by hand and substract from it the one representing X.
 
-    * When wishing to get the subset of columns to operate on, in
-      `fit_transform` or `transform` time, it is attained by calling
-      `self._get_columns(df, fit=True)` (or with `fit=False` if just
-      transforming), providing it the input dataframe.
+* When wishing to get the subset of columns to operate on, in
+  `fit_transform` or `transform` time, it is attained by calling
+  `self._get_columns(df, fit=True)` (or with `fit=False` if just
+  transforming), providing it the input dataframe.
 
-    * Additionally, to get a description and application message with a nice
-      string representation of the list of columns to operate on, the
-      `desc_temp` constructor parameter of ColumnsBasedPipelineStage can be
-      provided with a format string with a place holder where the column list
-      should go. E.g. `"Drop columns {}"` for the DropCol pipeline stage.
+* Additionally, to get a description and application message with a nice
+  string representation of the list of columns to operate on, the
+  `desc_temp` constructor parameter of ColumnsBasedPipelineStage can be
+  provided with a format string with a place holder where the column list
+  should go. E.g. `"Drop columns {}"` for the DropCol pipeline stage.
 
 There are two correct ways to extend it, depending on whether the pipeline
 stage you're creating is inherently fittable or not:
 
-    1. If the stage is NOT inherently fittable, then the ability to accept
-       fittable column qualifier objects makes it so. However, to enable
-       extending subclasses to implement their transformation using a single
-       method, they can simply implement the abstract method
-       `_transformation(self, df, verbose, fit)`. It should treat the `df` and
-       `verbose` parameters normally, but forward the `fit` parameter to the
-       `_get_columns` method when calling it. This is enough to get a pipeline
-       stage with the desired behavior, with the super-class handling all the
-       fit/transform functionality.
+1. If the stage is NOT inherently fittable, then the ability to accept
+   fittable column qualifier objects makes it so. However, to enable
+   extending subclasses to implement their transformation using a single
+   method, they can simply implement the abstract method
+   `_transformation(self, df, verbose, fit)`. It should treat the `df` and
+   `verbose` parameters normally, but forward the `fit` parameter to the
+   `_get_columns` method when calling it. This is enough to get a pipeline
+   stage with the desired behavior, with the super-class handling all the
+   fit/transform functionality.
 
-    2. If the stage IS inherently fittable, then do not use the
-       `_transformation` abstract method (it has to be implemented, so just
-       have it raise a NotImplementedError). Instead, simply override the
-       `_fit_transform` and `_transform` method of ColumnsBasedPipelineStage,
-       calling the `fit` parameter of the `_get_columns` method with the
-       correct arguement: `True` when fit-transforming and `False` when
-       transforming.
+2. If the stage IS inherently fittable, then do not use the
+   `_transformation` abstract method (it has to be implemented, so just
+   have it raise a NotImplementedError). Instead, simply override the
+   `_fit_transform` and `_transform` method of ColumnsBasedPipelineStage,
+   calling the `fit` parameter of the `_get_columns` method with the
+   correct arguement: `True` when fit-transforming and `False` when
+   transforming.
 
 Again, taking a look at the VERY concise implementation of simple columns-based
 stages, like ColDrop or ValDrop, will probably make things clearer, and you can
@@ -244,8 +244,9 @@ class PdPipelineStage(abc.ABC):
     skip : callable, default None
         This can be assigned a callable that returns boolean values for input
         dataframes, which will be used to determine whether this stage should
-        be skipped for input dataframes. See pdp.cond for more information on
-        specialised Condition objects.
+        be skipped for input dataframes - if the callable returns True for an
+        input dataframe, this stage will be skipped. See pdp.cond for more
+        information on specialised Condition objects.
     name : str, default ''
         The name of this stage. Pipelines can be sliced by this name.
 
